@@ -12,6 +12,7 @@
 #' @param horizontal Logical. When TRUE (the default), the plot has horizontal lines. When FALSE, the plot is reversed to show vertical lines. Horizontal lines are more appropriate for categorical caterpillar plots, because the x-axis is the only dimension that matters. But for caterpillar plots against another variable, the vertical position is more appropriate.
 #' @param model_labels Vector of strings that matches the number of models in the list. It is only used in case of multiple models and when the list of ggs objects given at \code{D} is not named. Otherwise, the names in the list are used.
 #' @param greek Logical value indicating whether parameter labels have to be parsed to get Greek letters. Defaults to false.
+#' @param sort Logical value indicating whether, in a horizontal display, y-axis labels must be sorted (the default) or not.
 #' @return A \code{ggplot} object.
 #' @export
 #' @examples
@@ -20,7 +21,7 @@
 #' ggs_caterpillar(list(A=ggs(s), B=ggs(s))) # silly example duplicating the same model
 ggs_caterpillar <- function(D, family=NA, X=NA, 
   thick_ci=c(0.05, 0.95), thin_ci=c(0.025, 0.975),
-  line=NA, horizontal=TRUE, model_labels=NULL, greek=FALSE) {
+  line=NA, horizontal=TRUE, model_labels=NULL, greek=FALSE, sort=TRUE) {
   
   # Manage subsetting a family of parameters
   if (!is.na(family)) {
@@ -75,10 +76,16 @@ ggs_caterpillar <- function(D, family=NA, X=NA,
   # Plot, depending on continuous or categorical x
   #
   if (!x.present) {
-    f <- ggplot(dcm, aes(x=median, y=reorder(Parameter, median))) + geom_point(size=3) +
-      geom_segment(aes(x=Low, xend=High, yend=reorder(Parameter, median)), size=1.5) +
-      geom_segment(aes(x=low, xend=high, yend=reorder(Parameter, median)), size=0.5) +
-      xlab("HPD") + ylab("Parameter")
+    if (sort) {
+      f <- ggplot(dcm, aes(x=median, y=reorder(Parameter, median), yend=reorder(Parameter, median))) + geom_point(size=3) +
+        geom_segment(aes(x=Low, xend=High), size=1.5) +
+        geom_segment(aes(x=low, xend=high), size=0.5)
+    } else {
+      f <- ggplot(dcm, aes(x=median, y=Parameter, yend=Parameter)) + geom_point(size=3) +
+        geom_segment(aes(x=Low, xend=High), size=1.5) +
+        geom_segment(aes(x=low, xend=high), size=0.5)
+    }
+    f <- f + xlab("HPD") + ylab("Parameter")
     if (greek) {
       f <- f + scale_y_discrete(labels = parse(text = as.character(dcm$Parameter[order(dcm$median)])))
     }
