@@ -2,6 +2,7 @@
 #'
 #' Internal function used by \code{\link{ggs_autocorrelation}}.
 #'
+#' @references Fernández-i-Marín, Xavier (2016) ggmcmc: Analysis of MCMC Samples and Bayesian Inference. Journal of Statistical Software, 70(9), 1-20. doi:10.18637/jss.v070.i09
 #' @param R data frame with the 'value' (predicted probability) and the observed 'Outcome'.
 #' @return A data frame with the Sensitivity and the Specificity.
 #' @export
@@ -36,13 +37,12 @@ ggs_rocplot <- function(D, outcome, fully_bayesian=FALSE) {
   } else {
     D.predicted <- D %>%
       group_by(Parameter, Chain) %>%
-      dplyr::summarize(value=quantile(value, 0.5))
+      dplyr::summarize(value=quantile(value, 0.5)) %>%
+      dplyr::ungroup()
   }
   roc.df <- dplyr::left_join(D.predicted, D.observed, by="Parameter")
   # Compute the roc curve using the roc_calc function
-  # As of dplyr 0.2 cbind must be used.
-  # Later on, this may change with cbind_list
-  roc.df <- cbind(roc.df, roc_calc(dplyr::select(roc.df, value, Observed)))
+  roc.df <- dplyr::bind_cols(roc.df, roc_calc(dplyr::select(roc.df, value, Observed)))
   # Sort it to be sure that the figure is plotted nicely
   roc.df <- dplyr::tbl_df(roc.df) %>%
     dplyr::filter(Sensitivity, Specificity)
