@@ -8,13 +8,16 @@
 #' @param original_burnin Logical. When TRUE (the default) start the Iteration counter in the x-axis at the end of the burnin period.
 #' @param original_thin Logical. When TRUE (the default) take into account the thinning interval in the x-axis.
 #' @param simplify Numerical. A percentage of iterations to keep in the time series. It is an option intended only for the purpose of saving time and resources when doing traceplots. It is not a thin operation, because it is not regular. It must be used with care.
+#' @param hpd Logical indicating whether HPD intervals (using the defaults from ci()) must be added to the plot. It is FALSE by default.
 #' @param greek Logical value indicating whether parameter labels have to be parsed to get Greek letters. Defaults to false.
 #' @return A \code{ggplot} object.
 #' @export
 #' @examples
 #' data(linear)
 #' ggs_traceplot(ggs(s))
-ggs_traceplot <- function(D, family=NA, original_burnin=TRUE, original_thin=TRUE, simplify=NULL, greek=FALSE) {
+ggs_traceplot <- function(D, family = NA, 
+                          original_burnin = TRUE, original_thin = TRUE, simplify = NULL, 
+                          hpd = FALSE, greek=FALSE) {
   # Manage subsetting a family of parameters
   if (!is.na(family)) {
     D <- get_family(D, family=family)
@@ -42,6 +45,18 @@ ggs_traceplot <- function(D, family=NA, original_burnin=TRUE, original_thin=TRUE
   }
   f <- f + geom_line(alpha=0.7) + 
     scale_colour_discrete(name="Chain")
+  if (hpd) {
+    ciD <- ci(D)
+    min.iteration <- min(D$Iteration)
+    max.iteration <- max(D$Iteration)
+    offset <- min.iteration - ((max.iteration - min.iteration) * 0.01)
+    f <- f + geom_segment(data = ciD, size = 0.5, inherit.aes = FALSE,
+                          aes(x = offset, xend = offset,
+                              y = low, yend = high)) +
+             geom_segment(data = ciD, size = 2, inherit.aes = FALSE,
+                          aes(x = offset, xend = offset,
+                              y = Low, yend = High))
+  }
   if (!greek) {
     f <- f + facet_wrap(~ Parameter, ncol=1, scales="free")
   } else {
